@@ -1,6 +1,9 @@
 """Methods to verify previously created pacts."""
+import os
+import platform
 import sys
-from os.path import isfile
+from os import listdir
+from os.path import isfile, isdir, join
 
 import click
 
@@ -20,7 +23,7 @@ else:
 @click.option(
     'pact_url', '--pact-url',
     help='The URI of the pact to verify.'
-         ' Can be an HTTP URI or a local file path.'
+         ' Can be an HTTP URI, a local file or directory path. '
          ' It can be specified multiple times to verify several pacts.',
     multiple=True)
 @click.option(
@@ -51,8 +54,19 @@ else:
     help='The duration in seconds we should wait to confirm verification'
          ' process was successful. Defaults to 30.',
     type=int)
-def main(base_url, pact_url, pact_urls, states_url, states_setup_url, username,
-         password, timeout):
+@click.option(
+    'provider_app_version', '-a', '--provider-app-version',
+    help='The provider application version, '
+         'required for publishing verification results'
+    )
+@click.option(
+    'publish_verification_results', '-r', '--publish-verification-results',
+    default=False,
+    help='Publish verification results to the broker',
+    is_flag=True)
+def main(base_url, pact_url, pact_urls, states_url,
+         states_setup_url, username, password, timeout, provider_app_version,
+         publish_verification_results):
     """
     Verify one or more contracts against a provider service.
 
@@ -79,6 +93,7 @@ def main(base_url, pact_url, pact_urls, states_url, states_setup_url, username,
             + ' At least one of --pact-url or --pact-urls is required.')
         raise click.Abort()
 
+    all_pact_urls = expand_directories(all_pact_urls)
     missing_files = [path for path in all_pact_urls if not path_exists(path)]
     if missing_files:
         click.echo(
@@ -94,15 +109,52 @@ def main(base_url, pact_url, pact_urls, states_url, states_setup_url, username,
         '--broker-username': username,
         '--broker-password': password
     }
-
     command = [VERIFIER_PATH] + [
         '{}={}'.format(k, v) for k, v in options.items() if v]
 
-    p = subprocess.Popen(command)
+    if publish_verification_results:
+        if not provider_app_version:
+            click.echo(
+                error
+                + 'Provider application version is required '
+                + 'to publish verification results to broker'
+            )
+            raise click.Abort()
+        command.extend(["--provider-app-version",
+                        provider_app_version,
+                        "--publish-verification-results"])
+
+    env = os.environ.copy()
+    env['PACT_INTERACTION_RERUN_COMMAND'] = rerun_command()
+    p = subprocess.Popen(command, env=env)
     p.communicate(timeout=timeout)
     sys.exit(p.returncode)
 
 
+def expand_directories(paths):
+    """
+    Iterate over paths and expand any that are directories into file paths.
+
+    :param paths: A list of file paths to expand.
+    :type paths: list
+    :return: A list of file paths with any directory paths replaced with the
+        JSON files in those directories.
+    :rtype: list
+    """
+    paths_ = []
+    for path in paths:
+        if path.startswith('http://') or path.startswith('https://'):
+            paths_.append(path)
+        elif isdir(path):
+            paths_.extend(
+                [join(path, p) for p in listdir(path) if p.endswith('.json')])
+        else:
+            paths_.append(path)
+
+    # Ruby pact verifier expects forward slashes regardless of OS
+    return [p.replace('\\', '/') for p in paths_]
+
+
 def path_exists(path):
     """
     Determine if a particular path exists.
@@ -121,5 +173,26 @@ def path_exists(path):
     return isfile(path)
 
 
+def rerun_command():
+    """
+    Create a rerun command template for failed interactions.
+
+    :rtype: str
+    """
+    is_windows = 'windows' in platform.platform().lower()
+    if is_windows:
+        return (
+            'cmd.exe /v /c "'
+            'set PACT_DESCRIPTION=<PACT_DESCRIPTION>'
+            '& set PACT_PROVIDER_STATE=<PACT_PROVIDER_STATE>'
+            '& {command}'
+            ' & set PACT_DESCRIPTION='
+            ' & set PACT_PROVIDER_STATE="'.format(command=' '.join(sys.argv)))
+    else:
+        return ("PACT_DESCRIPTION='<PACT_DESCRIPTION>'"
+                " PACT_PROVIDER_STATE='<PACT_PROVIDER_STATE>'"
+                " {command}".format(command=' '.join(sys.argv)))
+
+
 if __name__ == '__main__':
     sys.exit(main())
